#################################################################
# Appendix S09
# Three important tasks:
#  1) Plot Figure 2B
#  2) Generate data for Table S9.2
#  3) Use day-by-day worm count data to make an 'average' trajectory for each supertype-based genotype group
#     Makes maximum use of all available data points, with minimal influence of missing cases


#------------------------------------------------------------------------------------------------------------
# clear R; setwd
rm(list=ls())
setwd("Appendix_S09_makeFigures")

# Load packages
library(MASS)
library(MuMIn)
library(pscl)

# Load gyro data
gyro.data <- read.csv("appS09_02_forSupTypGraph.csv", stringsAsFactors=FALSE)
str(gyro.data)
names(gyro.data)

# For this dataset, we will use the date AS a date
gyro.data$date.infected <- as.Date(gyro.data$date.infected, "%d/%m/%Y")
#------------------------------------------------------------------------------------------------------------



#------------------------------------------------------------------------------------------------------------
# Load and re-format thermal data

# Load
thermal.Z.data <- read.csv("THERMAL_DATA_maxmidday_as_Zscore_2017-02-06.csv")

# Use date as rownames
row.names(thermal.Z.data) <- as.character(thermal.Z.data$date)

# Remove date column and turn rest into matrix
thermal.Z.data <- as.matrix( thermal.Z.data[2:ncol(thermal.Z.data)] )
#------------------------------------------------------------------------------------------------------------



#------------------------------------------------------------------------------------------------------------
# Put the variable 'ORDERED.CATEG' to work
#  - 0 = fish died
#  - 1 = fish still had increasing infection at day 17
#  - 2 = fish was still infected, but infection declining at day 17
#  - 3 = fish clear at end of experiment
#  - NA = fish called as 'clear' but found to have one or more gyrodactylid at a later check
#         these fish were dropped from the main worm-day analyses
#         but are included here

# Make two versions of the dataset
#  - one which retains the parameters that will be used for plotting pie charts
#    count deaths, clearances, and the rest
#    only needs select columns
#  - the other with numerical count data and with dead fish removed
#    non-zero and non-NA rows

gyro.data.DEATH <- gyro.data[c("fishID", "death", "day.dead", "day.clear", "clear", "novLoc.supTyp.3lev")]
gyro.data.LIVE <- gyro.data[which(gyro.data$ORDERED.CATEG != 0 | is.na(gyro.data$ORDERED.CATEG)), ]

# To avoid accidentally accessing the 'full' dataset, remove it
#
rm(gyro.data)

#------------------------------------------------------------------------------------------------------------



#------------------------------------------------------------------------------------------------------------
# FUNCTION DEFINITIONS

##########
## Get thermal data for a given gyro record
##   - to be used inside a function that will get a subset of gyro data
##
thermal.funct <- function(fish.row, screen.day, T.DATA=thermal.Z.data){
  
  # Get screening day as a string starting with 'd.'
  day.string <- ifelse(screen.day < 10, paste0("d.0", screen.day), paste0("d.", screen.day))
  
  # Get gyro load for that day. It will not be NA, because this will be run inside another function that removes NAs
  g.load <- fish.row[day.string][[1]]
  days.to.count <- screen.day
  
  # If it's zero worms, find out when the fish cleared and overwrite days.to.count and day.string
  #   - BUT WATCH OUT FOR 'COMEBACK' FISH
  #   - treat both clearances as legitimate, but get date of MOST RECENT ONE
  #     these have ORDERED.CATEG == NA
  if(g.load == 0){
    
    # Do the COMEBACK fish first
    if(is.na(fish.row["ORDERED.CATEG"][[1]])){
      # Get full infection traj. as vector
      full.traj <- as.vector(fish.row[c("d.00", "d.01", "d.03", "d.05", "d.07", "d.09", "d.11", "d.13", "d.15", "d.17")])
      # Get day seq
      day.seq <- c(0,1,3,5,7,9,11,13,15,17)
      # Cut off both from current day backwards
      full.traj <- full.traj[1:which(day.seq == screen.day)]
      day.seq <- day.seq[1:which(day.seq == screen.day)]
      # Get index of last non-zero; add 1; get the value from the dayseq; use THAT as days.to.count
      days.to.count <- day.seq[max(which(full.traj > 0)) + 1]
    }	else {
      
      # Do the 'regular' zeros
      days.to.count <- fish.row["day.clear"][[1]]
      day.string <- ifelse(days.to.count < 10, paste0("d.0", days.to.count), paste0("d.", days.to.count))
    }
  }
  
  # Get infected date
  start.date <- fish.row["date.infected"][[1]]
  end.date <- start.date + days.to.count
  
  # Get thermal data and return it
  therm.outData <- T.DATA[as.character(end.date), day.string]
  
  return(therm.outData)
}	## End of function
##
##########


##########
## Get a focal screening day's subset dataframe
##   - no NAs
##   - add thermal data
##
gyro.count.subset <- function(screening.day, G.DATA=gyro.data.LIVE){
  # make the 'day' part of the subsetting string
  day.string <- ifelse(screening.day < 10, paste0("d.0", screening.day), paste0("d.", screening.day))
  
  # Remove any NAs that this column might contain
  new.data <- G.DATA[!is.na(G.DATA[day.string]), ]
  
  # Add the thermal data
  new.data$temperature.Z <- sapply(1:nrow(new.data), 
	function(x) thermal.funct(new.data[x,], screening.day))  
  
  # Return
  return(new.data)
}	## End of function
##
##########


##########
## Get dAICc of best model to feature novLoc.alleles or novLoc.supTyp.3lev
##   (supertypes are not used in this script, but means function can be copied)
##   Pass it a dredge object
##   - if the predictor is not in best model, just get straight delta
##   - if predictor is in best, get first model to NOT feature it and return that as a negative value
##
BEST.dAICc <- function(MOD.TAB, mod.type, pred.to.get){
  # Alleles first
  if(pred.to.get == "novLoc.alleles"){
    if(mod.type == "poisson"){
      best.ST.n <- min(which(!is.na(MOD.TAB$novLoc.alleles)))
      OUT.delta <- ifelse(best.ST.n > 1,
		MOD.TAB$delta[best.ST.n],
		0-MOD.TAB$delta[min(which(is.na(MOD.TAB$novLoc.alleles)))] )
    
    }else if(mod.type == "hurdle_count"){
      best.ST.n <- min(which(!is.na(MOD.TAB$count_novLoc.alleles)))
      OUT.delta <- ifelse(best.ST.n > 1,
		MOD.TAB$delta[best.ST.n],
		0-MOD.TAB$delta[min(which(is.na(MOD.TAB$count_novLoc.alleles)))] )
    
    }else if(mod.type == "hurdle_zero"){
      best.ST.n <- min(which(!is.na(MOD.TAB$zero_novLoc.alleles)))
      OUT.delta <- ifelse(best.ST.n > 1,
		MOD.TAB$delta[best.ST.n],
		0-MOD.TAB$delta[min(which(is.na(MOD.TAB$zero_novLoc.alleles)))] )
    }
  
  }else if(pred.to.get == "novLoc.supTyp.3lev"){
    if(mod.type == "poisson"){
      best.sc3.n <- min(which(!is.na(MOD.TAB$novLoc.supTyp.3lev)))
      OUT.delta <- ifelse(best.sc3.n > 1,
		MOD.TAB$delta[best.sc3.n],
		0-MOD.TAB$delta[min(which(is.na(MOD.TAB$novLoc.supTyp.3lev)))] )
    
    }else if(mod.type == "hurdle_count"){
      best.sc3.n <- min(which(!is.na(MOD.TAB$count_novLoc.supTyp.3lev)))
      OUT.delta <- ifelse(best.sc3.n > 1,
		MOD.TAB$delta[best.sc3.n],
		0-MOD.TAB$delta[min(which(is.na(MOD.TAB$count_novLoc.supTyp.3lev)))] )
    
    }else if(mod.type == "hurdle_zero"){
      best.sc3.n <- min(which(!is.na(MOD.TAB$zero_novLoc.supTyp.3lev)))
      OUT.delta <- ifelse(best.sc3.n > 1,
		MOD.TAB$delta[best.sc3.n],
		0-MOD.TAB$delta[min(which(is.na(MOD.TAB$zero_novLoc.supTyp.3lev)))] )
    }
  }
  
  return(OUT.delta)
}	## End of function
##
##########


##########
## Get lowest P-value of best model to feature novLoc.supTyp.3lev or novLoc.supTyp.3lev
##   (P-values of the novLoc predictor)
##   - rationale for this is that it shows if a signficant contrast is present
##
BEST.Pvalue <- function(MOD, mod.type, pred.to.get){
  
  # Get coefficient table for model type
  if(mod.type == "poisson"){
    coef.tab <- summary(MOD)$coefficients
  }else if(mod.type == "hurdle_count"){
    coef.tab <- summary(MOD)$coefficients$count
  }else if(mod.type == "hurdle_zero"){
    coef.tab <- summary(MOD)$coefficients$zero
  }
  
  # Reduce to focal rows
  coef.tab <- coef.tab[which(grepl("novLoc[.]", rownames(coef.tab))),]
  
  # Get minimum P-value; round to 5dp
  min.P <- round(min(coef.tab[,"Pr(>|z|)"]), 5)
  
  return(min.P)
}	## End of function
##
##########

#------------------------------------------------------------------------------------------------------------



#------------------------------------------------------------------------------------------------------------
# Go through each screening day
#  - get its focal data subset
#  - find the best form of model
#    poisson, negbin, hurd.negbin
#    hurdle can be intercept-only or with predictors
#  - make the maximum model and dredge it
#    if hurdle with predictor is justified, dredge count and hurdle separately
#  - retrieve the best model
#    this will require manual assembly if count and hurdle both require modeling
#  - retrieve the delta-AICc of the best model to include novLoc
#    and see what the lowest P-value of novLoc is
#    THESE GO INTO TABLE S9.2 of supplementary material

# At end of each day's function, make a list
#  - day
#  - dataset
#  - model
#  - pair of AICc
#  - pair of min novLoc P-values
# THEN REMOVE EXCESS OBJECTS

tmpListNames <- c("day.N", "day.data", "day.model", "day.dAICc", "day.P")

####################################################
####################################################
# Day 1
# Poisson, no hurdle

# Get data subset
data.d01 <- gyro.count.subset(1)

# Start with Poisson
d01.pois.max <- glm(d.01 ~ replicate.pop + novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z,
	family="poisson", data=data.d01, na.action=na.fail)

d01.pois.max.dredge <- dredge(d01.pois.max)
d01.pois.max.dredge[d01.pois.max.dredge$delta<=2.5]


# Best by 1.82 has NO TERMS
#  - and replicate.pop doesn't make the top set!

# Check the top model's goodness-of-fit
#
d01.top <- get.models(d01.pois.max.dredge, 1)[[1]]
1-pchisq(d01.top$deviance, d01.top$df.residual)
#
# Fine for Poisson: P=1

# Get number of best ST model; get the model, and its summary
#
(d01.best.ST.n <- min(which(!is.na(d01.pois.max.dredge$novLoc.supTyp.3lev))))
d01.best.ST.mod <- get.models(d01.pois.max.dredge, d01.best.ST.n)[[1]]
summary(d01.best.ST.mod)

###
# FOR GRAPH, use d01.best.ST.mod
###

# Collect dAICc of novLoc.supTyp.3lev, and lowest P-value
#
d01.AICc.C <- BEST.dAICc(d01.pois.max.dredge, mod.type="poisson", pred.to.get="novLoc.supTyp.3lev")
d01.AICc.Z <- NA
d01.AICc.alleles <- c(d01.AICc.C, d01.AICc.Z)
d01.minP.C <- BEST.Pvalue(d01.best.ST.mod, mod.type="poisson", pred.to.get="novLoc.supTyp.3lev")
d01.minP.Z <- NA
d01.minP.alleles <- c(d01.minP.C, d01.minP.Z)

# These will be used in making Table S9.1 and Figure 2a
d01.AICc.alleles
d01.minP.alleles
summary(d01.best.ST.mod)$coefficients

d01.list <- list(1, data.d01, d01.best.ST.mod, d01.AICc.alleles, d01.minP.alleles)
names(d01.list) <- tmpListNames
rm(data.d01, d01.best.ST.mod, d01.AICc.alleles, d01.minP.alleles)


####################################################
####################################################
# Day 3
# Poisson, no hurdle

data.d03 <- gyro.count.subset(3)

# Start with Poisson
d03.pois.max <- glm(d.03 ~ replicate.pop + novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z,
	family="poisson", data=data.d03, na.action=na.fail)

d03.pois.max.dredge <- dredge(d03.pois.max)
d03.pois.max.dredge[d03.pois.max.dredge$delta<=2.5]

# Top model contain novLoc.supTyp.3lev

# Check the top model's goodness-of-fit
#
d03.top <- get.models(d03.pois.max.dredge, 1)[[1]]
1-pchisq(d03.top$deviance, d03.top$df.residual)
#
# Fine for Poisson: P=0.88

# Get number of best ST model; get the model, and its summary
#
(d03.best.ST.n <- min(which(!is.na(d03.pois.max.dredge$novLoc.supTyp.3lev))))
d03.best.ST.mod <- get.models(d03.pois.max.dredge, d03.best.ST.n)[[1]]
summary(d03.best.ST.mod)

###
# FOR GRAPH, use d03.best.ST.mod
###

# Collect dAICc of novLoc.supTyp.3lev, and lowest P-value
#
d03.AICc.C <- BEST.dAICc(d03.pois.max.dredge, mod.type="poisson", pred.to.get="novLoc.supTyp.3lev")
d03.AICc.Z <- NA
d03.AICc.alleles <- c(d03.AICc.C, d03.AICc.Z)
d03.minP.C <- BEST.Pvalue(d03.best.ST.mod, mod.type="poisson", pred.to.get="novLoc.supTyp.3lev")
d03.minP.Z <- NA
d03.minP.alleles <- c(d03.minP.C, d03.minP.Z)

# These will be used in making Table S9.1 and Figure 2a
d03.AICc.alleles
d03.minP.alleles
summary(d03.best.ST.mod)$coefficients

d03.list <- list(3, data.d03, d03.best.ST.mod, d03.AICc.alleles, d03.minP.alleles)
names(d03.list) <- tmpListNames
rm(data.d03, d03.best.ST.mod, d03.AICc.alleles, d03.minP.alleles)



####################################################
####################################################
# Day 5
# NB with constant hurdle

# Data subset
data.d05 <- gyro.count.subset(5)

# Are there any clearances (zeros); if so, is it safe/wise to try to predict?
#
sum(data.d05$d.05 == 0)		# 3; too few to predict

# Start with Poisson
d05.pois.max <- glm(d.05 ~ replicate.pop + novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z,
	family="poisson", data=data.d05, na.action=na.fail)

d05.pois.max.dredge <- dredge(d05.pois.max)
d05.pois.max.dredge[d05.pois.max.dredge$delta<=2.5]

# Top model contain novLoc.supTyp.3lev

# Check the top model's goodness-of-fit
#
d05.pois.top <- get.models(d05.pois.max.dredge, 1)[[1]]
1-pchisq(d05.pois.top$deviance, d05.pois.top$df.residual)
#
# BAD FOR POISSON: P=0

# Move to NB without hurdle
d05.NB.max <- glm.nb(d.05 ~ replicate.pop + novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z,
	data=data.d05, na.action=na.fail)

d05.NB.max.dredge <- dredge(d05.NB.max)
d05.NB.max.dredge[d05.NB.max.dredge$delta<=2.5]

# Topset has changed - novLoc.supTyp.3lev not in topmost
#  - check the top model's goodness-of-fit
#
d05.NB.top <- get.models(d05.NB.max.dredge, 1)[[1]]
1-pchisq(d05.NB.top$deviance, d05.NB.top$df.residual)
#
# Just sig - so go to hurdle

# Hurdle with negative binomial for counts
#  - intercept-only for hurdle
d05.hurdnb.max <- hurdle(d.05 ~ (replicate.pop + novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z)|1, 
	dist="negbin", data = data.d05, na.action = na.fail)

d05.hurdnb.max.dredge <- dredge(d05.hurdnb.max)
d05.hurdnb.max.dredge[d05.hurdnb.max.dredge$delta<=2.5]

# Compare AICc to see if adding zero is worth it
#
d05.NB.max.dredge$AICc[1]
d05.hurdnb.max.dredge$AICc[1]
#
# Nearly 10units' gain!

# novLoc.supTyp.3lev in topset

# Get number of best ST model; get the model, and its summary
#
(d05.best.ST.n <- min(which(!is.na(d05.hurdnb.max.dredge$count_novLoc.supTyp.3lev))))
d05.best.ST.mod <- get.models(d05.hurdnb.max.dredge, d05.best.ST.n)[[1]]
summary(d05.best.ST.mod)

# Both the negbin theta parameter and the hurdle intercept are signficantly different from zero

###
# FOR GRAPH, use d05.best.ST.mod
###

# Collect dAICc of novLoc.supTyp.3lev
d05.AICc.C <- BEST.dAICc(d05.hurdnb.max.dredge, mod.type="hurdle_count", pred.to.get="novLoc.supTyp.3lev")
d05.AICc.Z <- NA
d05.AICc.alleles <- c(d05.AICc.C, d05.AICc.Z)
d05.minP.C <- BEST.Pvalue(d05.best.ST.mod, mod.type="hurdle_count", pred.to.get="novLoc.supTyp.3lev")
d05.minP.Z <- NA
d05.minP.alleles <- c(d05.minP.C, d05.minP.Z)

# These will be used in making Table S9.1 and Figure 2a
d05.AICc.alleles
d05.minP.alleles
summary(d05.best.ST.mod)$coefficients

d05.list <- list(5, data.d05, d05.best.ST.mod, d05.AICc.alleles, d05.minP.alleles)
names(d05.list) <- tmpListNames
rm(data.d05, d05.best.ST.mod, d05.AICc.alleles, d05.minP.alleles)



####################################################
####################################################
# Day 7
# NB with constant hurdle

data.d07 <- gyro.count.subset(7)
sum(data.d07$d.07 == 0)			# 8; too few to predict

# Go straight to negbin hurdles
d07.hurdnb.max <- hurdle(d.07 ~ (replicate.pop + novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z)|1, 
	dist="negbin", data = data.d07, na.action = na.fail)

d07.hurdnb.max.dredge <- dredge(d07.hurdnb.max)
d07.hurdnb.max.dredge[d07.hurdnb.max.dredge$delta<=2.5]

# novLoc.supTyp.3lev out of top set, but n.supTyps present

# Get number of best ST model; get the model, and its summary
#
(d07.best.ST.n <- min(which(!is.na(d07.hurdnb.max.dredge$count_novLoc.supTyp.3lev))))
d07.best.ST.mod <- get.models(d07.hurdnb.max.dredge, d07.best.ST.n)[[1]]
summary(d07.best.ST.mod)

###
# FOR GRAPH, use d07.best.ST.mod
###

# Collect dAICc and lowest P of novLoc.supTyp.3lev
d07.AICc.C <- BEST.dAICc(d07.hurdnb.max.dredge, mod.type="hurdle_count", pred.to.get="novLoc.supTyp.3lev")
d07.AICc.Z <- NA
d07.AICc.alleles <- c(d07.AICc.C, d07.AICc.Z)
d07.minP.C <- BEST.Pvalue(d07.best.ST.mod, mod.type="hurdle_count", pred.to.get="novLoc.supTyp.3lev")
d07.minP.Z <- NA
d07.minP.alleles <- c(d07.minP.C, d07.minP.Z)

# These will be used in making Table S9.1 and Figure 2a
d07.AICc.alleles
d07.minP.alleles
summary(d07.best.ST.mod)$coefficients

d07.list <- list(7, data.d07, d07.best.ST.mod, d07.AICc.alleles, d07.minP.alleles)
names(d07.list) <- tmpListNames
rm(data.d07, d07.best.ST.mod, d07.AICc.alleles, d07.minP.alleles)



####################################################
####################################################
# Day 9
# NB with hurdle - allow prediction

data.d09 <- gyro.count.subset(9)
sum(data.d09$d.09 == 0)				# 26 - worth predicting
sum(data.d09$d.09 == 0)/nrow(data.d09)	# 12.7%

# Do separate dredges of Count and Zero

d09.hurdnb.max.C <- hurdle(d.09 ~ (replicate.pop + novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z)|1,
	dist="negbin", data=data.d09, na.action=na.fail)

d09.hurdnb.max.Z <- hurdle(d.09 ~ 1|(replicate.pop + novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z),
	dist="negbin", data=data.d09, na.action=na.fail)

# Do dredges
d09.hurdnb.dredge.C <- dredge(d09.hurdnb.max.C)
d09.hurdnb.dredge.C[d09.hurdnb.dredge.C$delta<=2.5]
d09.hurdnb.dredge.Z <- dredge(d09.hurdnb.max.Z)
d09.hurdnb.dredge.Z[d09.hurdnb.dredge.Z$delta<=2.5]

# novLoc.supTyp.3lev in topset for zeros

# Get number of best novLoc.supTyp.3lev models
(d09.best.n.C <- min(which(!is.na(d09.hurdnb.dredge.C$count_novLoc.supTyp.3lev))))
(d09.best.n.Z <- min(which(!is.na(d09.hurdnb.dredge.Z$zero_novLoc.supTyp.3lev))))

# Get best novLoc.supTyp.3lev models
d09.best.ST.mod.C <- get.models(d09.hurdnb.dredge.C, d09.best.n.C)[[1]]
d09.best.ST.mod.Z <- get.models(d09.hurdnb.dredge.Z, d09.best.n.Z)[[1]]

# Summaries
summary(d09.best.ST.mod.C)
summary(d09.best.ST.mod.Z)

# Population is producing stupid SEs for zeros, so drop it entirely
d09.hurdnb.max.Z.v2 <- hurdle(d.09 ~ 1|(novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z),
	dist="negbin", data=data.d09, na.action=na.fail)

d09.hurdnb.dredge.Z.v2 <- dredge(d09.hurdnb.max.Z.v2)
d09.hurdnb.dredge.Z.v2[d09.hurdnb.dredge.Z.v2$delta<=2.5]
# novLoc.supTyp.3lev still in top set

# Get new best hurdle model
#
(d09.best.n.Z.v2 <- min(which(!is.na(d09.hurdnb.dredge.Z.v2$zero_novLoc.supTyp.3lev))))
d09.best.ST.mod.Z.v2 <- get.models(d09.hurdnb.dredge.Z.v2, d09.best.n.Z.v2)[[1]]
summary(d09.best.ST.mod.Z.v2)
#
# Sensible, though novLoc has lost its slight significance (coefficient of novel still similar, but others have changed)

# ALTERNATIVE would be to try pooling some of the populations
#
table( data.d09$d.09 == 0, data.d09$replicate.pop )

# AV_SS has no zeros, and is the cause of the problem
#  - GR_Lop has second lowest in absolute (1) and proportional (2.9%)
#  - could try pooling these

data.d09$replicate.pop.POOL.d09 <- ifelse(data.d09$replicate.pop %in% c("AV_SS", "GR_Lop"), 
	"AV_SS_GR_Lop", data.d09$replicate.pop)

d09.hurdnb.max.Z.v3 <- hurdle(d.09 ~ 1|(replicate.pop.POOL.d09 + novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z),
	dist="negbin", data=data.d09, na.action=na.fail)

d09.hurdnb.dredge.Z.v3 <- dredge(d09.hurdnb.max.Z.v3)
d09.hurdnb.dredge.Z.v3[d09.hurdnb.dredge.Z.v3$delta<=2.5]

# Get new best hurdle model
#
(d09.best.n.Z.v3 <- min(which(!is.na(d09.hurdnb.dredge.Z.v3$zero_novLoc.supTyp.3lev))))
d09.best.ST.mod.Z.v3 <- get.models(d09.hurdnb.dredge.Z.v3, d09.best.n.Z.v2)[[1]]
summary(d09.best.ST.mod.Z.v3)
#
# Also sensible, novLoc.nov is nearer significance

summary(d09.best.ST.mod.Z.v2)
summary(d09.best.ST.mod.Z.v3)

# In the submitted work, I used v2
#  - thinking about it now, I'd probably use v3 if doing it again
#    Hard call, and arguable
#  - as preparing this data upload, I was tempted to change it
#    on balance, I won't, but I leave the alternative here for a sceptical reader to explore
#    in respect of novel v. local, it is more conservative to stick with v2
#    but there is a bit of movement in how 'mixed' sit

# USE VERSION 2
#  - and make it the 'official' best
d09.best.ST.mod.Z <- d09.best.ST.mod.Z.v2
summary(d09.best.ST.mod.Z)

###
# For GRAPH, need to combine count and hurdle
###

# To do this, turn the formulae to strings, split by '|', and extract the appropriate piece
#  - join them together, turn back to formula, and run
#
d09.best.C.string <- strsplit(as.character(d09.best.ST.mod.C$formula)[[3]], "[|]")[[1]][1]
d09.best.Z.string <- strsplit(as.character(d09.best.ST.mod.Z$formula)[[3]], "[|]")[[1]][2]
d09.best.combo.string <- paste0("d.09 ~ (", d09.best.C.string, ")|(", d09.best.Z.string, ")")
d09.best <- hurdle(as.formula(d09.best.combo.string),
	dist="negbin", data=data.d09, na.action=na.fail)

# Collect dAICc and lowest P of novLoc.supTyp.3lev
d09.AICc.C <- BEST.dAICc(d09.hurdnb.dredge.C, mod.type="hurdle_count", pred.to.get="novLoc.supTyp.3lev")
d09.AICc.Z <- BEST.dAICc(d09.hurdnb.dredge.Z, mod.type="hurdle_zero", pred.to.get="novLoc.supTyp.3lev")
d09.AICc.alleles <- c(d09.AICc.C, d09.AICc.Z)
d09.minP.C <- BEST.Pvalue(d09.best.ST.mod.C, mod.type="hurdle_count", pred.to.get="novLoc.supTyp.3lev")
d09.minP.Z <- BEST.Pvalue(d09.best.ST.mod.Z, mod.type="hurdle_zero", pred.to.get="novLoc.supTyp.3lev")
d09.minP.alleles <- c(d09.minP.C, d09.minP.Z)

# These will be used in making Table S9.1 and Figure 2a
d09.AICc.alleles
d09.minP.alleles
summary(d09.best)$coefficients

d09.list <- list(9, data.d09, d09.best, d09.AICc.alleles, d09.minP.alleles)
names(d09.list) <- tmpListNames
rm(data.d09, d09.best, d09.AICc.alleles, d09.minP.alleles)



####################################################
####################################################
# Day 11
# NB with hurdle

data.d11 <- gyro.count.subset(11)
sum(data.d11$d.11 == 0)				# 42 - worth predicting
sum(data.d11$d.11 == 0)/nrow(data.d11)	# 19.8%

# Do separate dredges of Count and Zero

d11.hurdnb.max.C <- hurdle(d.11 ~ (replicate.pop + novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z)|1,
	dist="negbin", data=data.d11, na.action=na.fail)

d11.hurdnb.max.Z <- hurdle(d.11 ~ 1|(replicate.pop + novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z),
	dist="negbin", data=data.d11, na.action=na.fail)

# Do dredges
d11.hurdnb.dredge.C <- dredge(d11.hurdnb.max.C)
d11.hurdnb.dredge.C[d11.hurdnb.dredge.C$delta<=2.5]
d11.hurdnb.dredge.Z <- dredge(d11.hurdnb.max.Z)
d11.hurdnb.dredge.Z[d11.hurdnb.dredge.Z$delta<=2.5]

# novLoc.supTyp.3lev not in either topset

# Get number of best novLoc.supTyp.3lev models; get models; get summaries
#
(d11.best.n.C <- min(which(!is.na(d11.hurdnb.dredge.C$count_novLoc.supTyp.3lev))))
(d11.best.n.Z <- min(which(!is.na(d11.hurdnb.dredge.Z$zero_novLoc.supTyp.3lev))))
#
# Get best novLoc.supTyp.3lev models
d11.best.ST.mod.C <- get.models(d11.hurdnb.dredge.C, d11.best.n.C)[[1]]
d11.best.ST.mod.Z <- get.models(d11.hurdnb.dredge.Z, d11.best.n.Z)[[1]]
#
summary(d11.best.ST.mod.C)
summary(d11.best.ST.mod.Z)
# Look sensible - no issues with silly SEs
#  - every population now has some zeros

###
# For GRAPH, need to get combo
###

# Combine count and hurdle, as was done for d09
#
d11.best.C.string <- strsplit(as.character(d11.best.ST.mod.C$formula)[[3]], "[|]")[[1]][1]
d11.best.Z.string <- strsplit(as.character(d11.best.ST.mod.Z$formula)[[3]], "[|]")[[1]][2]
d11.best.combo.string <- paste0("d.11 ~ (", d11.best.C.string, ")|(", d11.best.Z.string, ")")
d11.best <- hurdle(as.formula(d11.best.combo.string),
	dist="negbin", data=data.d11, na.action=na.fail)

# Collect dAICc of novLoc.supTyp.3lev
d11.AICc.C <- BEST.dAICc(d11.hurdnb.dredge.C, mod.type="hurdle_count", pred.to.get="novLoc.supTyp.3lev")
d11.AICc.Z <- BEST.dAICc(d11.hurdnb.dredge.Z, mod.type="hurdle_zero", pred.to.get="novLoc.supTyp.3lev")
d11.AICc.alleles <- c(d11.AICc.C, d11.AICc.Z)
d11.minP.C <- BEST.Pvalue(d11.best.ST.mod.C, mod.type="hurdle_count", pred.to.get="novLoc.supTyp.3lev")
d11.minP.Z <- BEST.Pvalue(d11.best.ST.mod.Z, mod.type="hurdle_zero", pred.to.get="novLoc.supTyp.3lev")
d11.minP.alleles <- c(d11.minP.C, d11.minP.Z)

# These will be used in making Table S9.1 and Figure 2a
d11.AICc.alleles
d11.minP.alleles
summary(d11.best)$coefficients

d11.list <- list(11, data.d11, d11.best, d11.AICc.alleles, d11.minP.alleles)
names(d11.list) <- tmpListNames
rm(data.d11, d11.best, d11.AICc.alleles, d11.minP.alleles)



####################################################
####################################################
# Day 13
# NB with hurdle

data.d13 <- gyro.count.subset(13)
sum(data.d13$d.13 == 0)				# 62 - worth predicting
sum(data.d13$d.13 == 0)/nrow(data.d13)	# 29.2%

# Do separate dredges of Count and Zero

d13.hurdnb.max.C <- hurdle(d.13 ~ (replicate.pop + novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z)|1,
	dist="negbin", data=data.d13, na.action=na.fail)

d13.hurdnb.max.Z <- hurdle(d.13 ~ 1|(replicate.pop + novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z),
	dist="negbin", data=data.d13, na.action=na.fail)

# Do dredges
d13.hurdnb.dredge.C <- dredge(d13.hurdnb.max.C)
d13.hurdnb.dredge.C[d13.hurdnb.dredge.C$delta<=2.5]
d13.hurdnb.dredge.Z <- dredge(d13.hurdnb.max.Z)
d13.hurdnb.dredge.Z[d13.hurdnb.dredge.Z$delta<=2.5]

# novLoc.supTyp.3lev in count topset

# Get number of best novLoc.supTyp.3lev models; get models; get summaries
(d13.best.n.C <- min(which(!is.na(d13.hurdnb.dredge.C$count_novLoc.supTyp.3lev))))
(d13.best.n.Z <- min(which(!is.na(d13.hurdnb.dredge.Z$zero_novLoc.supTyp.3lev))))
#
d13.best.ST.mod.C <- get.models(d13.hurdnb.dredge.C, d13.best.n.C)[[1]]
d13.best.ST.mod.Z <- get.models(d13.hurdnb.dredge.Z, d13.best.n.Z)[[1]]
#
summary(d13.best.ST.mod.C)
summary(d13.best.ST.mod.Z)

# Looks OK, though some extreme P-values for DR_SC in both count and hurdle

###
# For GRAPH, need to get combo
###

# Assemble combo model as for d.11
d13.best.C.string <- strsplit(as.character(d13.best.ST.mod.C$formula)[[3]], "[|]")[[1]][1]
d13.best.Z.string <- strsplit(as.character(d13.best.ST.mod.Z$formula)[[3]], "[|]")[[1]][2]
d13.best.combo.string <- paste0("d.13 ~ (", d13.best.C.string, ")|(", d13.best.Z.string, ")")
d13.best <- hurdle(as.formula(d13.best.combo.string),
	dist="negbin", data=data.d13, na.action=na.fail)

# Collect dAICc of novLoc.supTyp.3lev
d13.AICc.C <- BEST.dAICc(d13.hurdnb.dredge.C, mod.type="hurdle_count", pred.to.get="novLoc.supTyp.3lev")
d13.AICc.Z <- BEST.dAICc(d13.hurdnb.dredge.Z, mod.type="hurdle_zero", pred.to.get="novLoc.supTyp.3lev")
d13.AICc.alleles <- c(d13.AICc.C, d13.AICc.Z)
d13.minP.C <- BEST.Pvalue(d13.best.ST.mod.C, mod.type="hurdle_count", pred.to.get="novLoc.supTyp.3lev")
d13.minP.Z <- BEST.Pvalue(d13.best.ST.mod.Z, mod.type="hurdle_zero", pred.to.get="novLoc.supTyp.3lev")
d13.minP.alleles <- c(d13.minP.C, d13.minP.Z)

# These will be used in making Table S9.1 and Figure 2a
d13.AICc.alleles
d13.minP.alleles
summary(d13.best)$coefficients

# WARNING: the dAICc for hurdle is slightly different from that in Table S9.1
#  - further exploration has shown that this is an error in the table-making and not in the analysis
#    for whatever reason, the wrong value has been entered into the table

d13.list <- list(13, data.d13, d13.best, d13.AICc.alleles, d13.minP.alleles)
names(d13.list) <- tmpListNames
rm(data.d13, d13.best, d13.AICc.alleles, d13.minP.alleles)



####################################################
####################################################
# Day 15
# NB with hurdle

data.d15 <- gyro.count.subset(15)
sum(data.d15$d.15 == 0)				# 82 - worth predicting
sum(data.d15$d.15 == 0)/nrow(data.d15)	# 38.7%

# Do separate dredges of Count and Zero

d15.hurdnb.max.C <- hurdle(d.15 ~ (replicate.pop + novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z)|1,
	dist="negbin", data=data.d15, na.action=na.fail)

d15.hurdnb.max.Z <- hurdle(d.15 ~ 1|(replicate.pop + novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z),
	dist="negbin", data=data.d15, na.action=na.fail)

# Do dredges
d15.hurdnb.dredge.C <- dredge(d15.hurdnb.max.C)
d15.hurdnb.dredge.C[d15.hurdnb.dredge.C$delta<=2.5]
d15.hurdnb.dredge.Z <- dredge(d15.hurdnb.max.Z)
d15.hurdnb.dredge.Z[d15.hurdnb.dredge.Z$delta<=2.5]

# novLoc.supTyp.3lev in count topset

# Get number of best super.class.3.v2 models
(d15.best.n.C <- min(which(!is.na(d15.hurdnb.dredge.C$count_novLoc.supTyp.3lev))))
(d15.best.n.Z <- min(which(!is.na(d15.hurdnb.dredge.Z$zero_novLoc.supTyp.3lev))))
#
# Get best novLoc.supTyp.3lev models
d15.best.ST.mod.C <- get.models(d15.hurdnb.dredge.C, d15.best.n.C)[[1]]
d15.best.ST.mod.Z <- get.models(d15.hurdnb.dredge.Z, d15.best.n.Z)[[1]]
#
# Summaries
summary(d15.best.ST.mod.C)
summary(d15.best.ST.mod.Z)
# Look sensible

###
# For GRAPH, need to get combo
###

# Assemble combo model as for d.13

d15.best.C.string <- strsplit(as.character(d15.best.ST.mod.C$formula)[[3]], "[|]")[[1]][1]
d15.best.Z.string <- strsplit(as.character(d15.best.ST.mod.Z$formula)[[3]], "[|]")[[1]][2]
d15.best.combo.string <- paste0("d.15 ~ (", d15.best.C.string, ")|(", d15.best.Z.string, ")")
as.formula(d15.best.combo.string)
d15.best <- hurdle(as.formula(d15.best.combo.string),
	dist="negbin", data=data.d15, na.action=na.fail)

# Collect dAICc of novLoc.supTyp.3lev
d15.AICc.C <- BEST.dAICc(d15.hurdnb.dredge.C, mod.type="hurdle_count", pred.to.get="novLoc.supTyp.3lev")
d15.AICc.Z <- BEST.dAICc(d15.hurdnb.dredge.Z, mod.type="hurdle_zero", pred.to.get="novLoc.supTyp.3lev")
d15.AICc.alleles <- c(d15.AICc.C, d15.AICc.Z)
d15.minP.C <- BEST.Pvalue(d15.best.ST.mod.C, mod.type="hurdle_count", pred.to.get="novLoc.supTyp.3lev")
d15.minP.Z <- BEST.Pvalue(d15.best.ST.mod.Z, mod.type="hurdle_zero", pred.to.get="novLoc.supTyp.3lev")
d15.minP.alleles <- c(d15.minP.C, d15.minP.Z)

# These will be used in making Table S9.1 and Figure 2a
d15.AICc.alleles
d15.minP.alleles
summary(d15.best)$coefficients

d15.list <- list(15, data.d15, d15.best, d15.AICc.alleles, d15.minP.alleles)
names(d15.list) <- tmpListNames
rm(data.d15, d15.best, d15.AICc.alleles, d15.minP.alleles)



####################################################
####################################################
# Day 17
# NB with hurdle

data.d17 <- gyro.count.subset(17)
sum(data.d17$d.17 == 0)				# 112 - worth predicting
sum(data.d17$d.17 == 0)/nrow(data.d17)	# 52.8%

# Do separate dredges of Count and Zero

d17.hurdnb.max.C <- hurdle(d.17 ~ (replicate.pop + novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z)|1,
	dist="negbin", data=data.d17, na.action=na.fail)

d17.hurdnb.max.Z <- hurdle(d.17 ~ 1|(replicate.pop + novLoc.supTyp.3lev + n.supTyps + 
		length.scaled + age.sex + temperature.Z),
	dist="negbin", data=data.d17, na.action=na.fail)

# Do dredges
d17.hurdnb.dredge.C <- dredge(d17.hurdnb.max.C)
d17.hurdnb.dredge.C[d17.hurdnb.dredge.C$delta<=2.5]
d17.hurdnb.dredge.Z <- dredge(d17.hurdnb.max.Z)
d17.hurdnb.dredge.Z[d17.hurdnb.dredge.Z$delta<=2.5]

# novLoc.supTyp.3lev in both topsets

# Get number of best super.class.3.v2 models
(d17.best.n.C <- min(which(!is.na(d17.hurdnb.dredge.C$count_novLoc.supTyp.3lev))))
(d17.best.n.Z <- min(which(!is.na(d17.hurdnb.dredge.Z$zero_novLoc.supTyp.3lev))))

# Get best novLoc.supTyp.3lev models
d17.best.ST.mod.C <- get.models(d17.hurdnb.dredge.C, d17.best.n.C)[[1]]
d17.best.ST.mod.Z <- get.models(d17.hurdnb.dredge.Z, d17.best.n.Z)[[1]]

# Summaries
summary(d17.best.ST.mod.C)
summary(d17.best.ST.mod.Z)
# Look sensible

###
# For GRAPH, need to get combo
###

# Assemble combo model as for d.15

d17.best.C.string <- strsplit(as.character(d17.best.ST.mod.C$formula)[[3]], "[|]")[[1]][1]
d17.best.Z.string <- strsplit(as.character(d17.best.ST.mod.Z$formula)[[3]], "[|]")[[1]][2]
d17.best.combo.string <- paste0("d.17 ~ (", d17.best.C.string, ")|(", d17.best.Z.string, ")")
as.formula(d17.best.combo.string)
d17.best <- hurdle(as.formula(d17.best.combo.string),
	dist="negbin", data=data.d17, na.action=na.fail)

# Collect dAICc of novLoc.supTyp.3lev
d17.AICc.C <- BEST.dAICc(d17.hurdnb.dredge.C, mod.type="hurdle_count", pred.to.get="novLoc.supTyp.3lev")
d17.AICc.Z <- BEST.dAICc(d17.hurdnb.dredge.Z, mod.type="hurdle_zero", pred.to.get="novLoc.supTyp.3lev")
d17.AICc.alleles <- c(d17.AICc.C, d17.AICc.Z)
d17.minP.C <- BEST.Pvalue(d17.best.ST.mod.C, mod.type="hurdle_count", pred.to.get="novLoc.supTyp.3lev")
d17.minP.Z <- BEST.Pvalue(d17.best.ST.mod.Z, mod.type="hurdle_zero", pred.to.get="novLoc.supTyp.3lev")
d17.minP.alleles <- c(d17.minP.C, d17.minP.Z)

# These will be used in making Table S9.1 and Figure 2a
d17.AICc.alleles
d17.minP.alleles
summary(d17.best)$coefficients

d17.list <- list(17, data.d17, d17.best, d17.AICc.alleles, d17.minP.alleles)
names(d17.list) <- tmpListNames
rm(data.d17, d17.best, d17.AICc.alleles, d17.minP.alleles)


#------------------------------------------------------------------------------------------------------------



#------------------------------------------------------------------------------------------------------------
# Gathering and tidying of these model summaries
# Generating the values for use in plotting Figure 2


##########
## Function to make data for building a 'mean infection trajectory' graph
## Pass it an infection day's dataset and the day's best model
## To make the 'mean loads' for each genotype group (local, mixed, novel):
##   - make a copy of the whole dataset
##   - set every fish to have the focal genotype (local, mixed or novel)
##   - generate a predicted value for all fish
##     - for hurdle models, this is the "response" category of predicted values
##     - for Poisson GLMs, the predicted value is on natural log scale
##       for hurdles, it's 'real' numbers - so take natural log of these
##   - take the mean of these predicted values
##     within a focal day, this controls for all other predictors that may be in the model
##     i.e. every fish has a predicted value as if it were local, mixed, or novel
## For error bars, use the intercept SE for 'local', and the SEs of differences from 'local' for 'mixed' and 'novel'
##   - not perfect, but serves visual purpose
##
## TWO FUNCTIONS
##  - one to get the mean for a given genotype
##  - second to use this for all genotypes and gather other parts of output
##
get.geno.mean.counts <- function(MOD, DATA, genoString){
  # Make novLoc.supTyp.3lev as if it were all of the focal genotype
  DATA$novLoc.supTyp.3lev <- genoString
  
  # Next step is dependent on model class
  if(class(MOD)[1] == "glm"){
    DATA$PRED <- predict(MOD, DATA)
  }else if(class(MOD)[1] == "hurdle"){
    DATA$PRED <- predict(MOD, DATA, type="response")
    DATA$PRED <- log(DATA$PRED)
  }
  return(mean(DATA$PRED))
}	## End of function
##
##
##
get.graph.data <- function(DAY, DATA, MOD){
  # Turn day to string
  DAY.STRING <- ifelse(DAY < 10, paste0("d.0", DAY), paste0("d.", DAY))
  
  # Subset the data columns; rename gyro load column, so as to standardise for all days
  DATA <- DATA[c("replicate.pop", "n.supTyps", "novLoc.supTyp.3lev", 
	"temperature.Z", "age.sex", "length.scaled", DAY.STRING)]
  names(DATA)[ncol(DATA)] <- "LOAD"
  
  # Make novLoc.supTyp.3lev predicted values as if all fish were local, mixed, and novel
  mean.local <- get.geno.mean.counts(MOD, DATA, "local")
  mean.mixed <- get.geno.mean.counts(MOD, DATA, "mixed")
  mean.novel <- get.geno.mean.counts(MOD, DATA, "novel")
  
  # Get coefficient table, which is class-dependent
  if(class(MOD)[1] == "glm"){
    COEF.TAB <- summary(MOD)$coefficients
  }else if(class(MOD)[1] == "hurdle"){
    COEF.TAB <- summary(MOD)$coefficients$count
  }
  
  # Gather the plotdata, and reformat
  PLOT.DATA <- data.frame(
	novLoc.supTyp.3lev = c("local", "mixed", "novel"),
	mean = c(mean.local, mean.mixed, mean.novel),
	se = c(COEF.TAB["(Intercept)", "Std. Error"], 
	   COEF.TAB["novLoc.supTyp.3levmixed", "Std. Error"], 
	   COEF.TAB["novLoc.supTyp.3levnovel", "Std. Error"]),
	Day = rep(DAY,3),
	stringsAsFactors = FALSE )
  
  return(PLOT.DATA)
}	## End of function
##
##########


# Collect all of the day lists into a list-of-lists
graphList <- list(d01.list, d03.list, d05.list,
		d07.list, d09.list, d11.list,
		d13.list, d15.list, d17.list)

names(graphList) <- sapply(seq(1, 17, by=2), 
	function(x) ifelse(x<10, paste0("d.0", x), paste0("d.", x)))

# Apply the functions to this list to get the graph data
countGraphData <- do.call(rbind, 
	lapply(graphList, function(x) get.graph.data(x$day.N, x$day.data, x$day.model) ) )

# THIS IS THE DATA PRESENTED IN THE L/L, L/N and N/N columns of Table S9.1

# HERE ARE THE AICc DATA COLUMNS FOR Table S9.1
do.call(rbind, lapply(graphList, function(x) round(x$day.dAICc, 2)))

# HERE ARE THE LOWEST P-VALUES FOR novLoc.supTyp.3lev CONTRASTS
do.call(rbind, lapply(graphList, function(x) round(x$day.P, 3)))


# Prepare and add day 0's graph data manually
countGraphData <- rbind( 
  data.frame(novLoc.supTyp.3lev = c("local", "mixed", "novel"),
	mean = rep(log(2), 3),
	se = rep(NA, 3),
	Day = rep(0, 3),
	stringsAsFactors=FALSE),
  countGraphData )

# So the DF looks a little nicer for inspection...
rownames(countGraphData) <- NULL

# INSPECT AGAIN
countGraphData

# Quick reformat for ease of comparison to Table S9.2
round(countGraphData[countGraphData$novLoc.supTyp.3lev=="local", c("mean", "se")], 2)
round(countGraphData[countGraphData$novLoc.supTyp.3lev=="mixed", c("mean", "se")], 2)
round(countGraphData[countGraphData$novLoc.supTyp.3lev=="novel", c("mean", "se")], 2)

#------------------------------------------------------------------------------------------------------------



#------------------------------------------------------------------------------------------------------------
# Prepare the data for the boxplot inset
#  - this is the data AS ANALYSED for the main result
#    the worm-day area, dropping counts from days 7 and 9

# Create the data
#  - need to drop 'comeback' fish from this, as they were dropped for main analysis
gyro.data.LIVE.AREA <- gyro.data.LIVE[!is.na(gyro.data.LIVE$ORDERED.CATEG), ]

# Add the temperature.Z column
# But given other uses of temperature elsewhere in this script, call it 'temperature.Z.END'
#  - use the temperature function as for screening day 17
#
gyro.data.LIVE.AREA$temperature.Z.END <- sapply(1:nrow(gyro.data.LIVE.AREA), 
	function(x) thermal.funct(gyro.data.LIVE.AREA[x,], 17))

# Build the maximum model
wormDay.mod.max <- glm.nb(area.SUM.d79.1 ~ replicate.pop + age.sex + length.scaled + 
	novLoc.supTyp.3lev + n.supTyps + temperature.Z.END,
	data=gyro.data.LIVE.AREA, na.action=na.fail)

# Dredge it
wormDay.mod.dredge <- dredge(wormDay.mod.max)

# Verify that the top set is as presented in Table S2.2a
wormDay.mod.dredge[wormDay.mod.dredge$delta <= 2,]

# Yes, it matches

# For illustration purposes, take the best model to include novLoc.supTyp.3lev
#  - this is the top model
wormDay.mod.best <- get.models(wormDay.mod.dredge, 1)[[1]]

# Make predicted data, controlling for all other variables
#  - as I review this for data repository upload, I see I've done this control slightly differently from day-by-day counts
#    in those, I sequentially made the whole dataset as if it local, mixed and novel, keeping all other values as 'real'
#    for this area figure, I've used an expanded grid for factors and means for continuous
#    the differences should be small and not affect interpretation
#    but I would like to make the reader aware of this
#    and that I've only spotted it now, as I prepare the data for upload
# Still mulling over the pros and cons of each as I prepare this

wormDay.predData <- expand.grid(replicate.pop = unique(gyro.data.LIVE.AREA$replicate.pop),
	novLoc.supTyp.3lev = unique(gyro.data.LIVE.AREA$novLoc.supTyp.3lev),
	age.sex = unique(gyro.data.LIVE.AREA$age.sex),
	length.scaled = mean(gyro.data.LIVE.AREA$length.scaled),
	temperature.Z.END = mean(gyro.data.LIVE.AREA$temperature.Z.END),
	n.supTyps = mean(gyro.data.LIVE.AREA$n.supTyps),
	stringsAsFactors=FALSE)

wormDay.predData$pred <- predict(wormDay.mod.best, wormDay.predData)

# Get means for each genotype class
wormDay.predData.means <- tapply(wormDay.predData$pred, wormDay.predData$novLoc.supTyp.3lev, mean)

# Prepare plotting dataframe; first, predictor and residuals
boxPlotData <- data.frame(novLoc.supTyp.3lev = gyro.data.LIVE.AREA$novLoc.supTyp.3lev,
	resid = residuals(wormDay.mod.best),
	stringsAsFactors=FALSE)

# Add predicted values
boxPlotData$pred <- wormDay.predData.means[boxPlotData$novLoc.supTyp.3lev]

# Mean-centre residuals within genotype class
#
resid.means.genoClass <- tapply(boxPlotData$resid, boxPlotData$novLoc.supTyp.3lev, mean)
boxPlotData$resid.cent <- apply(boxPlotData, 1, 
	function(x) as.numeric(x["resid"]) - as.numeric(resid.means.genoClass[x["novLoc.supTyp.3lev"]]))

# Verify that values are as good as zero
tapply(boxPlotData$resid.cent, boxPlotData$novLoc.supTyp.3lev, mean)

# Add centred residuals to predicted values to get data to plot and illustrate data spread
boxPlotData$toPlot <- boxPlotData$pred + boxPlotData$resid.cent

# For the figure, capitalise the genotype names
boxPlotData$novLoc.supTyp.3lev[boxPlotData$novLoc.supTyp.3lev == "local"] <- "Local"
boxPlotData$novLoc.supTyp.3lev[boxPlotData$novLoc.supTyp.3lev == "mixed"] <- "Mixed"
boxPlotData$novLoc.supTyp.3lev[boxPlotData$novLoc.supTyp.3lev == "novel"] <- "Novel"

#------------------------------------------------------------------------------------------------------------



#------------------------------------------------------------------------------------------------------------
# PREPARE THE PIE CHARTS FIRST

# I ask readers to forgive the massively convoluted fine-tuning parameters
#  - but these are the parameters as produced the published figures
#  - it was my first go at building such a figure, and I'm not the most graphically-minded person!

# Load packages and set three-colour scheme
library(ggplot2)
require(cowplot)
TRICOLOUR <- c("#d55e00ff", "#cc79a7ff", "#0072b2ff")


# Get data subset for pies
DATA.FOR.PIES <- gyro.data.DEATH[c("fishID", "day.clear", "day.dead", "novLoc.supTyp.3lev", "clear")]

# Remove the comebacks - BUT REMEMBER YOU'VE DONE THIS
DATA.FOR.PIES <- DATA.FOR.PIES[DATA.FOR.PIES$clear != "COMEBACK",]

# Append '.pie' to day.dead and day.clear names
names(DATA.FOR.PIES)[names(DATA.FOR.PIES) == "day.clear"] <- "day.clear.pie"
names(DATA.FOR.PIES)[names(DATA.FOR.PIES) == "day.dead"] <- "day.dead.pie"

# Changed NAs into zeros for these two columns
#  - these are fish that don't clear and/or don't die
#
DATA.FOR.PIES$day.clear.pie[is.na(DATA.FOR.PIES$day.clear.pie)] <- 0
DATA.FOR.PIES$day.dead.pie[is.na(DATA.FOR.PIES$day.dead.pie)] <- 0


# Set the theme for the pies
pie_theme <- theme_minimal()+
  theme(axis.title.x = element_blank(),
  axis.title.y = element_blank(),
  panel.border = element_blank(),
  axis.text = element_blank(),
  panel.grid=element_blank(),
  axis.ticks = element_blank(),
  plot.title=element_text(size=14, face="bold"),
  legend.position = "none")


##########
## Function to apply to DATA.FOR.PIES to make data for a given day
## Makes a new vector of same length as DATA.FOR.PIES
## Want deaths to have 0, clear to have 2, infected to have 1
## Assumes no entries have values for both 'clear' and 'death' - which they shouldn't, and I can't see any errors
## Reason for that order of values is for aesthetics when it comes to the pies
##
DAY.PIE.class <- function(pieData, DAY){
  OUT <- 1
  OUT <- ifelse(pieData["day.dead.pie"] > 0 & pieData["day.dead.pie"] <= DAY, 0, OUT)
  OUT <- ifelse(pieData["day.clear.pie"] > 0 & pieData["day.clear.pie"] <= DAY, 2, OUT)
  return(OUT)
}	## End of function
##
##########


##########
## Function to make a set of three pies for a given day
## Give it the main pie-building dataframe as a constant
## Give it the pie theme and the colours
## Provide it with the focal day
## Provide it with parameters for setting out the three pies in ggdraw()
##   - 1,3,4 are constants; 2 is the vertical offset between each pie, e.g. 0.3 will plot at 0.0, 0.3, 0.6
## Return list of three pie objects
##
MAKE.PIE.SET <- function(D, plot.params, DATA=DATA.FOR.PIES, THEME=pie_theme, COLS=TRICOLOUR){
  # Make the day's pie data; combine it with novLoc.supTyp.3lev; rename cols, and turn to factor
  data.sub <- DAY.PIE.class(DATA,D)
  data.sub <- cbind(DATA["novLoc.supTyp.3lev"], data.sub)
  names(data.sub) <- c("novLoc.supTyp.3lev", "Fate")
  
  # Make the raw count table
  count.table <- table(data.sub$novLoc.supTyp.3lev, data.sub$Fate)
  
  # Check if all levels of 'Fate' are present; if not, make some data to add
  if(!"0" %in% colnames(count.table)){
    add.deathrows <- expand.grid(1:3, 0, 0)
    names(add.deathrows) <- c("novLoc.supTyp.3lev", "Fate", "Freq")
    add.deathrows$novLoc.supTyp.3lev <- factor(add.deathrows$novLoc.supTyp.3lev, labels=c("local", "mixed", "novel"))
  }
  if(!"2" %in% colnames(count.table)){
    add.cleanrows <- expand.grid(1:3, 2, 0)
    names(add.cleanrows) <- c("novLoc.supTyp.3lev", "Fate", "Freq")
    add.cleanrows$novLoc.supTyp.3lev <- factor(add.cleanrows$novLoc.supTyp.3lev, labels=c("local", "mixed", "novel"))
  }
  
  # Make DF version of count.table; turn 'Fate' to numeric
  count.table <- data.frame(count.table/rowSums(count.table))
  names(count.table) <- c("novLoc.supTyp.3lev", "Fate", "Freq")
  count.table$Fate <- as.numeric(count.table$Fate)
  
  # Check for data rows to add
  if(exists("add.deathrows")){
    count.table <- rbind(count.table, add.deathrows)
  }
  if(exists("add.cleanrows")){
    count.table <- rbind(count.table, add.cleanrows)
  }
  
  # Make local pie
  pie.local <- ggplot(data = subset(count.table, novLoc.supTyp.3lev=="local"), 
		aes(x=factor(1), y=Freq, fill=factor(Fate))) + 
	geom_bar(width = 1, stat="identity") + 
	coord_polar("y") + 
	scale_fill_manual(values=c("black", COLS[1], "light grey")) +
	pie_theme
  
  # Make mixed pie
  pie.mixed <- ggplot(data = subset(count.table, novLoc.supTyp.3lev=="mixed"), 
		aes(x=factor(1), y=Freq, fill=factor(Fate))) + 
	geom_bar(width = 1, stat="identity") + 
	coord_polar("y") + 
	scale_fill_manual(values=c("black", COLS[2], "light grey")) +
	pie_theme
  
  # Make novel pie
  pie.novel <- ggplot(data = subset(count.table, novLoc.supTyp.3lev=="novel"), 
		aes(x=factor(1), y=Freq, fill=factor(Fate))) + 
	geom_bar(width = 1, stat="identity") + 
	coord_polar("y") + 
	scale_fill_manual(values=c("black", COLS[3], "light grey")) +
	pie_theme
  
  # Make into single object
  # Use pie parameters
  X <- plot.params[1]
  Y <- plot.params[2]
  W <- plot.params[3]
  H <- plot.params[4]
  PIES.OUT <- ggdraw() +
	draw_plot(pie.novel, X, 0.0, W, H) + 
	draw_plot(pie.mixed, X, 0.0+Y, W, H) + 
	draw_plot(pie.local, X, 0.0+2*Y, W, H)
  
  # Return it
  return(PIES.OUT)
}	## End of function
##
##########

# Make the pies
#  1 = x offset - shouldn't need to change this
#  2 = y offset, e.g. 0.3 will plot at 0.0, 0.3, 0.6, relatively speaking
#  3&4 are width and height; height is the one to tweak at the moment - but can also tweak it in later code

PIE.STORE <- lapply(seq(1,17,2), function(x) MAKE.PIE.SET(D=x, plot.params=c(0, 0.315, 1.0, 0.55)))

#------------------------------------------------------------------------------------------------------------



#------------------------------------------------------------------------------------------------------------
# Make the trajectory graph

# Set parameters for use in the plot
dodge.value <- 0.5
X_LABELS <- paste0("Day ", c(0,1,3,5,7,9,11,13,15,17)); X_LABELS[1] <- "0"
AXIS_LABEL_SIZE <- 9.6
AXIS_TITLE_SIZE <- AXIS_LABEL_SIZE
LEG_LAB_SIZE <- AXIS_LABEL_SIZE
LEG_TITLE_SIZE <- AXIS_LABEL_SIZE
LINE_WIDTH <- 0.5
POINT_SIZE <- 1.2

# Main trajectory plot
plot.traj <- ggplot(aes(y = mean, x = Day, colour = novLoc.supTyp.3lev), data = countGraphData) + 
	geom_point(cex=POINT_SIZE, position=position_dodge(width=dodge.value)) +
	geom_line(position=position_dodge(width=dodge.value), lwd=LINE_WIDTH) +
	geom_errorbar(aes(ymin = mean - (1.96*se), 
		ymax = mean + (1.96*se)), 
		width=0.5, lwd=LINE_WIDTH, 
		position=position_dodge(width=dodge.value)) + 
	labs(x = "", y = "Infection intensity  [log(number of worms)]") +
	scale_x_continuous(breaks = c(0,1,3,5,7,9,11,13,15,17), labels = X_LABELS, minor_breaks = NULL) +
	scale_colour_manual(values=TRICOLOUR, 
		name = "MHC super-\ngenotype class",
		labels = c("Local/Local", "Local/Novel", "Novel/Novel"),
		guide = guide_legend(direction="vertical",
			title.position="top")) +
	theme(axis.text.x = element_text(size=AXIS_LABEL_SIZE),
		axis.text.y = element_text(size=AXIS_LABEL_SIZE),
		axis.title.x = element_text(size=AXIS_TITLE_SIZE, hjust=0.5),
		axis.title.y = element_text(size=AXIS_TITLE_SIZE, hjust=0.5),
		legend.title = element_text(size=LEG_TITLE_SIZE, face="plain"),
		legend.text = element_text(size = LEG_LAB_SIZE),
		legend.position = c(0.0335, 0.7625)) 

#------------------------------------------------------------------------------------------------------------



#------------------------------------------------------------------------------------------------------------
# Make the boxplot

# Set parameters for use in the plot
box.lwd <- LINE_WIDTH*0.7
box.axisThick <- 0.45

# Boxplot
BOXPLOT <- ggplot(boxPlotData, aes(novLoc.supTyp.3lev, toPlot)) +
	stat_boxplot(geom ='errorbar', 
		width=0.4, 
		lwd=box.lwd) + 
	geom_boxplot(notch=TRUE, 
		fill=TRICOLOUR, 
		lwd=box.lwd,
		outlier.size = 0.7) +
	labs(x = "", y = "Log(worm days)") +
	scale_x_discrete(labels=c("L/L", "L/N", "N/N")) + 
	theme(axis.text.x = element_text(size=AXIS_LABEL_SIZE),
		axis.text.y = element_text(size=AXIS_LABEL_SIZE,
						margin = margin(t = 0, r = 2.2, b = 0, l = 0)),
		axis.title.x = element_text(size=AXIS_LABEL_SIZE, hjust=0.5),
		axis.title.y = element_text(size=AXIS_LABEL_SIZE, 
						hjust=0.5,
						margin = margin(t = 0, r = 0, b = 0, l = 15)),
		axis.line.x = element_line(colour = 'black', size = box.axisThick),
		axis.ticks.x = element_line(colour = 'black', size = box.axisThick),
		axis.line.y = element_line(colour = 'black', size = box.axisThick),
		axis.ticks.y = element_line(colour = 'black', size = box.axisThick)) +
	scale_y_continuous(breaks = seq(4,10,2))

#------------------------------------------------------------------------------------------------------------



#------------------------------------------------------------------------------------------------------------
# Use cowplot to stick it all together!
# This is where things start to get seriously long-winded!


TRAJ.ADJUST <- 0.2			# To adjust the y-coord of the TRAJ graph, and automatically adjust its height
pie.width <- 0.2				# width for pie triads on main plot 
pie.height <- 0.27			# height for pie triads on main plot - 0.275
xpos.17 <- 0.827				# x-coord for 17th pie set
xpos.01 <- 0.078				# x-coord for 1st pie set - 0.703
xpos.int <- (xpos.17-xpos.01)/8	# Adjuster for each pie triad relative to days 1 and 17
ypos <- -0.031				# ycoord for pie triads

LAB.TXT <- AXIS_LABEL_SIZE				# Text size for pie and clear/dead labels
pie.lab.x.adj <- 0.0985					# Adjuster for x position of left-justified pie labels
pie.lab.y.top <- 0.2017					# ycoord for topmost pie label (vertically centred)
pie.lab.y.bot <- 0.0327					# ycoord for bottomost pie label (vertically centred)
pie.lab.y.mid <- (pie.lab.y.top+pie.lab.y.bot)/2	# ycoord for middle pie label

pie.col.key.X1 <- 0.030							# xmin for grey and black rectangles and text
pie.col.key.Xcoord <- c(pie.col.key.X1, pie.col.key.X1 + 0.037)	# xmin and xmax for positioning grey and black rectangles, and text
pie.col.key.Ycoord.text <- c(pie.lab.y.mid, pie.lab.y.top)		# ymins for text
rect.height <- 0.02								# Rectangle height
rect.vertPos.offset <- 0.03							# Height of rectangle ymin above text ymin
pie.col.key.Ycoord.rect <- c(pie.lab.y.mid+rect.vertPos.offset,	# Y coordinates for rectangles
		pie.lab.y.mid+rect.vertPos.offset+rect.height,
		pie.lab.y.top++rect.vertPos.offset, 
		pie.lab.y.top+rect.vertPos.offset+rect.height) 

BOX.x <- 0.3605			# Box x coord
BOX.y <- 0.276			# Box y coord
BOX.w <- 0.356			# Box width
BOX.h <- 0.434			# Box height

# Trajectory coords
TRAJ.Y <- 0.197
TRAJ.H <- 0.81

SUPERS.PLOT.TO.SAVE <- 
ggdraw() +
  draw_plot(plot.traj, 0, TRAJ.Y, 1, TRAJ.H) +
  draw_plot(BOXPLOT, BOX.x, BOX.y, BOX.w, BOX.h) +
  draw_plot(PIE.STORE[[1]], xpos.01, ypos, pie.width, pie.height) +
  draw_plot(PIE.STORE[[9]], xpos.17, ypos, pie.width, pie.height) +  
  draw_plot(PIE.STORE[[2]], xpos.01+ 1*xpos.int, ypos, pie.width, pie.height) +
  draw_plot(PIE.STORE[[3]], xpos.01+ 2*xpos.int, ypos, pie.width, pie.height) +
  draw_plot(PIE.STORE[[4]], xpos.01+ 3*xpos.int, ypos, pie.width, pie.height) +
  draw_plot(PIE.STORE[[5]], xpos.01+ 4*xpos.int, ypos, pie.width, pie.height) +
  draw_plot(PIE.STORE[[6]], xpos.01+ 5*xpos.int, ypos, pie.width, pie.height) +
  draw_plot(PIE.STORE[[7]], xpos.01+ 6*xpos.int, ypos, pie.width, pie.height) +
  draw_plot(PIE.STORE[[8]], xpos.01+ 7*xpos.int, ypos, pie.width, pie.height) +
  draw_label("N/N", x=pie.lab.x.adj, y=pie.lab.y.bot, size=LAB.TXT, hjust=1, vjust=0) +
  draw_label("L/N", x=pie.lab.x.adj, y=pie.lab.y.mid, size=LAB.TXT, hjust=1, vjust=0) +
  draw_label("L/L", x=pie.lab.x.adj, y=pie.lab.y.top, size=LAB.TXT, hjust=1, vjust=0) +
  draw_label("Fig. 2B", x=0.117, y=0.3435, hjust=0, vjust=0, size=AXIS_LABEL_SIZE)


#save_plot("MAIN_PLOT_supers_R_2018-01-07.svg",
#	SUPERS.PLOT.TO.SAVE, base_aspect_ratio=1.45)
#save_plot("MAIN_PLOT_supers_R_2018-01-07.pdf",
#	SUPERS.PLOT.TO.SAVE, base_aspect_ratio=1.45)
#save_plot("MAIN_PLOT_supers_R_2018-01-07.png",
#	SUPERS.PLOT.TO.SAVE, base_aspect_ratio=1.45)

#------------------------------------------------------------------------------------------------------------



#------------------------------------------------------------------------------------------------------------
# Use the day-by-day worm counts used for plotting the trajectory...
#   ...to caluclate and 'average' worm-day infection
# Makes maximum use of available count data, while minimising influence of incomplete cases

# Exponentiate the log-counts
#
area.data.all <- countGraphData[c("novLoc.supTyp.3lev", "mean", "Day")]
area.data.all$count <- exp(area.data.all$mean)

##########
## Function to calculate area of section
## Give it two counts and a day range
##
area.section <- function(val1, val2, days){
  COUNTS <- c(val1, val2)
  SQ <- days*min(COUNTS)
  TR <- ((max(COUNTS)-min(COUNTS))*days)/2
  TOT <- SQ+TR
  return(TOT)
}	## End of function
##
##########


# For each genotype, get the area for each day interval
#
area.data.all <- lapply(c("local", "mixed", "novel"), function(x){
  
  # Get subset of data for focal genotype
  DF <- area.data.all[area.data.all$novLoc.supTyp.3lev==x,]
  
  # Set AREA column as NA
  DF$AREA <- NA
  
  # Loop down the days, doing area caluclation
  for(i in 2:nrow(DF)){
    row.info <- c(DF[i, "count"], 
	DF[i-1, "count"], 
	DF[i, "Day"]-DF[i-1, "Day"])
    DF$AREA[i] <- area.section(row.info[1], row.info[2], row.info[3])
  }
  # Return
  return(DF)
 })


# Now get sums
AREA.SUMS <- unlist(lapply(area.data.all, function(x) sum(x$AREA, na.rm=TRUE)))
names(AREA.SUMS) <- c("local", "mixed", "novel")

1-(AREA.SUMS["mixed"]/AREA.SUMS["local"])		# -16.6%
1-(AREA.SUMS["novel"]/AREA.SUMS["local"])		# -34.7%


# The list of dataframes 'area.data.all' can also be used to focus on particular time windows
#  - e.g. days 1-7
AREA.SUMS.01.07 <- unlist(lapply(area.data.all, function(x) sum(x$AREA[1:5], na.rm=TRUE)))
AREA.SUMS.01.07

# Or days 13-17
AREA.SUMS.13.17 <- unlist(lapply(area.data.all, function(x) sum(x$AREA[8:10], na.rm=TRUE)))
AREA.SUMS.13.17
#------------------------------------------------------------------------------------------------------------

# END OF SCRIPT